@@ -1,8 +1,6 @@
-from typing import Type
-
+from typing import Type, List
 import pytest
 from pydantic import BaseModel, Field
-
 from pymultirole_plugins.v1.annotator import AnnotatorBase, AnnotatorParameters
 from pymultirole_plugins.v1.schema import Document, Category
 
@@ -28,11 +26,11 @@ class Dummyannotator(AnnotatorBase):
     """Dummy annotator.
     """
 
-    def annotate(self, document: Document, parameters: AnnotatorParameters) \
-            -> Document:
+    def annotate(self, documents: List[Document], parameters: AnnotatorParameters) \
+            -> List[Document]:
         parameters: DummyParameters = parameters
-        document.categories = [Category(labelName=parameters.foo, score=parameters.bar)]
-        return document
+        documents[0].categories = [Category(labelName=parameters.foo, score=parameters.bar)]
+        return documents
 
     @classmethod
     def get_model(cls) -> Type[BaseModel]:
@@ -42,7 +40,14 @@ class Dummyannotator(AnnotatorBase):
 def test_dummy():
     annotator = Dummyannotator()
     options = DummyParameters()
-    doc: Document = annotator.annotate(Document(text="This is a test document", metadata=options.dict()), options)
-    assert len(doc.categories) == 1
-    assert doc.categories[0].labelName == options.foo
-    assert doc.categories[0].score == options.bar
+    docs: List[Document] =\
+        annotator.annotate([Document(text="This is a test document", metadata=options.dict())], options)
+    assert len(docs[0].categories) == 1
+    assert docs[0].categories[0].labelName == options.foo
+    assert docs[0].categories[0].score == options.bar
+
+
+def test_singleton():
+    annotator1 = Dummyannotator()
+    annotator2 = Dummyannotator()
+    assert id(annotator2) == id(annotator1)
